---
name: Feature Request
about: Suggest an idea for the Neo4j GraphRAG library
labels: "feature request"
---

<!--
    If you are an Enterprise customer, you might want to head over to our
    [Customer Support Portal](https://support.neo4j.com/).
-->

<!--
    If you are unsure about the usage of this library, this issue tracker is not
    the right place to ask. Please use one of the following channels instead:

    - Neo4j Online Community: https://community.neo4j.com/
    - StackOverflow: https://stackoverflow.com/questions/tagged/neo4j+python
    - Discord: https://discord.gg/neo4j
    - Neo4j Support Portal if you are an enterprise customer:
      https://support.neo4j.com/
-->

<!--
    Make sure you've searched the issue tracker for similar issues first.
-->

# Feature Request
<!-- a brief description of what's requested -->

# Pitch
<!-- elaborate on the feature request and why it would be beneficial -->
